# Changelog

<!--next-version-placeholder-->

## v0.134.0 (2022-02-24)
### Feature
* Merge pull request #40 from l0kix2/gha_release

Release via github actions ([`9222567`](https://github.com/yandex-cloud/python-sdk/commit/92225671e201543711638cede06a818629cace85))
* Merge branch 'master' into gha_release ([`5f1b4b3`](https://github.com/yandex-cloud/python-sdk/commit/5f1b4b370fdf42268cbb71db42b8e879300a213c))
* Regenerate proto
 ([`465cde0`](https://github.com/yandex-cloud/python-sdk/commit/465cde0227fb25fd5095884acea6b428584fe52c))
* Regenerate proto
 ([`65c1c91`](https://github.com/yandex-cloud/python-sdk/commit/65c1c91612dc9399c0101d99900c414fd0377f34))
* Add workflow_dispatch feature for manual run
 ([`af8c27b`](https://github.com/yandex-cloud/python-sdk/commit/af8c27b5b632ecf18a222670cc8c47e292ef5cbe))
* Fix git creds
 ([`a436c93`](https://github.com/yandex-cloud/python-sdk/commit/a436c93d06a0ca01ceee5974c904c4dbd287426a))
* Real pypi in conf
 ([`e42bfaf`](https://github.com/yandex-cloud/python-sdk/commit/e42bfaf4bd5cf1269ca06c2a567b064d495f1588))
* Readme update
 ([`1b7a7bf`](https://github.com/yandex-cloud/python-sdk/commit/1b7a7bfb3aab35ce0dc9a21ed1f77f27f7e2372a))
* Simple changelog
 ([`e2273b0`](https://github.com/yandex-cloud/python-sdk/commit/e2273b097f16f5fa2cae05beb293eadab09ef691))
* Releasing by github actions
 ([`88f8cc8`](https://github.com/yandex-cloud/python-sdk/commit/88f8cc85efb6bee564d1255fa09e6a6f942b65e3))
* Bump version to 0.131.0 ([`914c17e`](https://github.com/yandex-cloud/python-sdk/commit/914c17ef05a41ba335834ab133a494665a06007d))
* Add alb to supported modules
 ([`890d07c`](https://github.com/yandex-cloud/python-sdk/commit/890d07c3b4cd0fa96751d2af17bf1381de76a3e3))
* Merge pull request #28 from peter-volkov/master

Exponential backoff for op get ([`910b864`](https://github.com/yandex-cloud/python-sdk/commit/910b864e36d42e8ef44ef1bd23a586e72054d88b))
* Bump
 ([`b2e95b9`](https://github.com/yandex-cloud/python-sdk/commit/b2e95b9eab9f49ab52e928c482b340d573d3ab8f))
* Unittest
 ([`373b4ac`](https://github.com/yandex-cloud/python-sdk/commit/373b4ac580d77aa9176a3db0cca590c8ed44583d))
* First time 50ms
 ([`55b0248`](https://github.com/yandex-cloud/python-sdk/commit/55b0248779f822015117ac1d1c0ae581246f7f9e))
* Add multiplied jitter
 ([`aaf76fc`](https://github.com/yandex-cloud/python-sdk/commit/aaf76fc491118e8e34841c9897b3e6a5ed9aca57))
* Add jitter
 ([`831e922`](https://github.com/yandex-cloud/python-sdk/commit/831e9226e9d68ff71646052a882996ecae2e88e9))
* Exponential backoff for op get
 ([`da7b5dc`](https://github.com/yandex-cloud/python-sdk/commit/da7b5dcdb78790abaa878f4a6a5a447ef28ce21d))
* Add github actions workflow for tests

Co-authored-by: Ivan Zuev <dajohnes@gmail.com>
 ([`d219545`](https://github.com/yandex-cloud/python-sdk/commit/d21954587520042b2dd8518e80afbc00447c8be5))
* Add Makefile
 ([`65fa995`](https://github.com/yandex-cloud/python-sdk/commit/65fa995df434d88f54ddbb53db8d1adc8fedb8e0))
* Use tox for testing
 ([`20e6def`](https://github.com/yandex-cloud/python-sdk/commit/20e6deffa75ec75fa3784f653e7433d17aa32ff5))
* Fix test for python3.6
 ([`b332f66`](https://github.com/yandex-cloud/python-sdk/commit/b332f66fe59d99c7434bc717a9dd71660d4c01a0))
* Merge pull request #25 from yandex-cloud/fix_service_account_key_test

Fix jwt.decode usage in test_service_account_key ([`5d99982`](https://github.com/yandex-cloud/python-sdk/commit/5d999826ca6e3c8736abff945685b4bf5239c3cc))
* Fix jwt.decode usage in test_service_account_key
 ([`585bfe1`](https://github.com/yandex-cloud/python-sdk/commit/585bfe11323637bba26a147075a7b8912fb0c6d9))
* Regenerate proto
 ([`36a0bcb`](https://github.com/yandex-cloud/python-sdk/commit/36a0bcbafdfaeecdd18439d7bf90bcfc1c49a8cb))
* Regenerate proto
 ([`6099ee9`](https://github.com/yandex-cloud/python-sdk/commit/6099ee9ca872d68e58bf90ba5092553fb7c921d5))
* Regenerate proto
 ([`388f6be`](https://github.com/yandex-cloud/python-sdk/commit/388f6be8d12d3ea722c471c522f7ecf7fae825df))
* Regenerate proto
 ([`d6f4408`](https://github.com/yandex-cloud/python-sdk/commit/d6f4408d917c71effc5365ec3298a41792ad4429))
* Merge pull request #24 from korsar182/patch-1

add cdn to supported modules ([`09e9d9f`](https://github.com/yandex-cloud/python-sdk/commit/09e9d9f41f527a9fda8e6f498030740cc53c1d55))
* Add cdn to supported modules ([`060060e`](https://github.com/yandex-cloud/python-sdk/commit/060060eb8b1eda0582d8f6eb7c2568b63c2399e5))
* Regenerate proto
 ([`873bf2a`](https://github.com/yandex-cloud/python-sdk/commit/873bf2a9b136a8f2faae72e86fae1f5b5c3d896a))
* Regenerate proto
 ([`b49c689`](https://github.com/yandex-cloud/python-sdk/commit/b49c6899609a5d425ff25ab31bd3c4696b6595b5))
* Regenerate proto
 ([`a763289`](https://github.com/yandex-cloud/python-sdk/commit/a7632895260fead3b12e16330aad51aef1ed5b63))
* Regenerate proto
 ([`ef3a6e8`](https://github.com/yandex-cloud/python-sdk/commit/ef3a6e864096348882c32da33dbb425c4c4c7e68))
* Merge pull request #22 from Piatachock/spark-packages-repos-excludes

Support GRPC User-Agent; [DataProc] support maven packages parameters, improve examples ([`e48bd1b`](https://github.com/yandex-cloud/python-sdk/commit/e48bd1b4cb218619947b4cbc6cf36452826779ab))
* DataProc: Support maven packages parameters in Spark jobs
 ([`9f18355`](https://github.com/yandex-cloud/python-sdk/commit/9f183550f5a6a41ff1ddd2993e5680d64aa00fde))
* Support GRPC user-agent in SDK

* Prepend User-Agent set by grpc library with `yandex-cloud-python-sdk/$VERSION` entry. Version is taken from pkg_resources
* Allow SDK clients to add their own User-Agent entry, which will be prepended to previous result.
 ([`12d5666`](https://github.com/yandex-cloud/python-sdk/commit/12d5666ccdfd94424cc9de070562b8bd3af9cf34))
* DataProc: Use uuid in examples/dataproc output folders for MapReduce job

Allows reusage of s3 bucket
 ([`35f39f0`](https://github.com/yandex-cloud/python-sdk/commit/35f39f092256992819e20afee27c45092cd126a8))
* Regenerate proto
 ([`b174897`](https://github.com/yandex-cloud/python-sdk/commit/b17489757a831681bcfedbabe1279370fe0a092b))
* Regenerate proto
 ([`df4566a`](https://github.com/yandex-cloud/python-sdk/commit/df4566a70ca5acf6f18052e295236bc799c5cc9d))
* Merge pull request #21 from Irioth/master

Add managed-elasticsearch to supported modules ([`40428d0`](https://github.com/yandex-cloud/python-sdk/commit/40428d0ff18012471deba7b93cacde584070677e))
* Added managed-elasticsearch to supported modules
 ([`06f2276`](https://github.com/yandex-cloud/python-sdk/commit/06f2276df603bf922ae01e0b5e559a8f53cf4e9b))
* Regenerate proto
 ([`eb29db7`](https://github.com/yandex-cloud/python-sdk/commit/eb29db7f1bddad2080f21620cb93bb02b8089c07))
* Regenerate proto
 ([`89d776c`](https://github.com/yandex-cloud/python-sdk/commit/89d776c819b473ae5522814401783c3c8ee2b1ff))
* Regenerate proto
 ([`b5297c8`](https://github.com/yandex-cloud/python-sdk/commit/b5297c88212e90a5087ea53b41ff5ea3bc9d62a2))
* Regenerate proto
 ([`03fa47c`](https://github.com/yandex-cloud/python-sdk/commit/03fa47c685bf433d4cefae209308c299cb04c48f))
* Regenerate proto
 ([`769730c`](https://github.com/yandex-cloud/python-sdk/commit/769730c4aadeb96a22427892a7451b49d2b09629))
* Regenerate proto
 ([`22c2b64`](https://github.com/yandex-cloud/python-sdk/commit/22c2b64642bcde15fea10e53b9190836b8f69c69))
* Regenerate proto
 ([`cfd01b6`](https://github.com/yandex-cloud/python-sdk/commit/cfd01b62d9376b419b74ad45160b9a730626addf))
* Regenerate proto
 ([`6cc063c`](https://github.com/yandex-cloud/python-sdk/commit/6cc063c5464ee25896ad921f571d6cdd9168ad02))
* Merge pull request #19 from peter-volkov/master

Log group usage in example ([`f54890a`](https://github.com/yandex-cloud/python-sdk/commit/f54890a1bfa4853f23ecb0ad65da7e3ef398a063))
* Regenerate proto
 ([`3009216`](https://github.com/yandex-cloud/python-sdk/commit/3009216ab8d4f941c15420a06baee38ea3caf6d3))
* Regenerate proto
 ([`b9e02c7`](https://github.com/yandex-cloud/python-sdk/commit/b9e02c7daaac80cd284268519d84e420ad41a759))
* Log group usage in example
 ([`cddf7c8`](https://github.com/yandex-cloud/python-sdk/commit/cddf7c8b758e5c5ed695c81932bcba12dad3bf2f))
* Regenerate proto
 ([`6ddaaaf`](https://github.com/yandex-cloud/python-sdk/commit/6ddaaaf0ad01d8fc36cb72957f70a6e7943a5ce7))
* Merge pull request #18 from GoncharovArtyom/billing_endpoint

Add billing ([`69b3d0d`](https://github.com/yandex-cloud/python-sdk/commit/69b3d0d83f6dbd22dd9dffa68a258ff15b3f0794))
* Add billing module to id mapping
 ([`5bb9155`](https://github.com/yandex-cloud/python-sdk/commit/5bb91558363ab33a170c65eab03300ad357279b5))
* Regenerate proto
 ([`cbeae7c`](https://github.com/yandex-cloud/python-sdk/commit/cbeae7c9bf0bf71c46e27762f73aca1d0aa31811))
* Regenerate proto
 ([`e324762`](https://github.com/yandex-cloud/python-sdk/commit/e324762a88cc4b9474d676f5c68fad3730e58561))
* Merge pull request #17 from yandex-cloud/fix/logging

update log ingestion (fix typo) ([`e85dbe9`](https://github.com/yandex-cloud/python-sdk/commit/e85dbe9e390b188209595a42c1199d29f661b702))
* Update log ingestion (fix typo)
 ([`fc39b47`](https://github.com/yandex-cloud/python-sdk/commit/fc39b4751e7046656ee04216712a239433ceb98f))
* Regenerate proto
 ([`7dfd1e3`](https://github.com/yandex-cloud/python-sdk/commit/7dfd1e38117614442b914b34311dcd55db7fe39c))
* Regenerate proto
 ([`2e469ab`](https://github.com/yandex-cloud/python-sdk/commit/2e469ab69dcb44e5fe9de7e5711b9c916360f174))
* Regenerate proto
 ([`a5a560f`](https://github.com/yandex-cloud/python-sdk/commit/a5a560f6fadc492b69ccadd4c9394c41152cf89c))
* Regenerate proto
 ([`ed9940a`](https://github.com/yandex-cloud/python-sdk/commit/ed9940a1a5e36de51ee972745e0a62379b9c5f7c))
* Sync up supported modules
 ([`eddaaf2`](https://github.com/yandex-cloud/python-sdk/commit/eddaaf28c4d9dcc4b63e7be5b0cd01e03fa70350))
* Regenerate proto
 ([`86a03db`](https://github.com/yandex-cloud/python-sdk/commit/86a03dbc6b7f7a52d02b5fe409fd59c87d0fe7d6))
* Regenerate proto
 ([`4d47784`](https://github.com/yandex-cloud/python-sdk/commit/4d477841e0988a434ec64868292afad6eedd6cb8))
* Regenerate proto
 ([`2794916`](https://github.com/yandex-cloud/python-sdk/commit/2794916113800e7815cf00cebb5f23a7bb1778ba))
* Regenerate proto
 ([`0ae9641`](https://github.com/yandex-cloud/python-sdk/commit/0ae9641eceb5f2a10c63388de0ad453a22b27238))
* Regenerate proto
 ([`6f5e111`](https://github.com/yandex-cloud/python-sdk/commit/6f5e1115b345506e8af42d988cc4455961f38c7d))
* Merge pull request #16 from peter-volkov/master

Retry grpc.StatusCode.INTERNAL and autoscaling support for Data Proc ([`24e60e0`](https://github.com/yandex-cloud/python-sdk/commit/24e60e0c3ed631717e43752412ac34b62a26d6c3))
* Add autoscaling subclusters support
 ([`9a71af8`](https://github.com/yandex-cloud/python-sdk/commit/9a71af855b9cd5766424a8e605073ebc62488f58))
* Retry count for interceptor
 ([`a13bb22`](https://github.com/yandex-cloud/python-sdk/commit/a13bb22758e9e26c095ed8cc78f560392f51f42e))
* Retry grpc.StatusCode.INTERNAL only for operation waiter
 ([`8706a45`](https://github.com/yandex-cloud/python-sdk/commit/8706a45e91225deb122ee552f1feda1250e178bf))
* Retry grpc.StatusCode.INTERNAL
 ([`85225c5`](https://github.com/yandex-cloud/python-sdk/commit/85225c5a761a683f3067aa42bfe4c98aa727ec76))
* Regenerate proto
 ([`ff0073a`](https://github.com/yandex-cloud/python-sdk/commit/ff0073a592f11289dcb5b225a0131bfabd911d0d))
* Regenerate proto
 ([`857b903`](https://github.com/yandex-cloud/python-sdk/commit/857b9035305897cc45a77b0531ca6b66e0dd9080))
* Regenerate proto
 ([`ad67811`](https://github.com/yandex-cloud/python-sdk/commit/ad67811e43f8cc9ae2684db5a3e8698f0d482756))
* Regenerate proto
 ([`0146ad5`](https://github.com/yandex-cloud/python-sdk/commit/0146ad57827ee19c41601d9bba1229cebd8af188))
* Regenerate proto
 ([`1f4b86a`](https://github.com/yandex-cloud/python-sdk/commit/1f4b86aa4178ffb9d82fd372cc17cc69bf0b429e))
* Regenerate proto
 ([`7b64a5c`](https://github.com/yandex-cloud/python-sdk/commit/7b64a5c800ac78a6ac41c82111d3e5d4b2566040))
* Regenerate proto
 ([`0252e55`](https://github.com/yandex-cloud/python-sdk/commit/0252e55df5a6243ccc723fe7942aa85a307ec523))
* Regenerate proto
 ([`4cc71dd`](https://github.com/yandex-cloud/python-sdk/commit/4cc71dd3415b987c93c4b63039000ce232c0ce35))
* Regenerate proto
 ([`e4763ab`](https://github.com/yandex-cloud/python-sdk/commit/e4763ab2e67f5aa7e50d29c09e651809699962c1))
* Regenerate proto
 ([`a9023e7`](https://github.com/yandex-cloud/python-sdk/commit/a9023e7e9dbb1bc6182f2a4147dabb90e5d12d0e))
* Regenerate proto
 ([`27d54a7`](https://github.com/yandex-cloud/python-sdk/commit/27d54a705f66f3887750c19698292579acb9bb89))
* Regenerate proto
 ([`0ad8b28`](https://github.com/yandex-cloud/python-sdk/commit/0ad8b283104e08752172fb4a4b889a0af95404a3))
* Regenerate proto
 ([`e2795cc`](https://github.com/yandex-cloud/python-sdk/commit/e2795cc57c204ebd3988d7451a459ae7252632f4))
* Regenerate proto
 ([`566664d`](https://github.com/yandex-cloud/python-sdk/commit/566664d634887f471bdf6c73463905cd2f632bab))
* Regenerate proto
 ([`d2dee73`](https://github.com/yandex-cloud/python-sdk/commit/d2dee73cfcbbf08cb0788b819135f4b4ad1c67ed))
* Regenerate proto
 ([`91ab04a`](https://github.com/yandex-cloud/python-sdk/commit/91ab04a4e50194b5478138ecea3a5b45068ae584))
* Merge pull request #15 from kbespalov/patch-1

[Marketplace Metering API] Improve example.py ([`95d6020`](https://github.com/yandex-cloud/python-sdk/commit/95d60208af424bdbcbd802d109828703c3733fdd))
* Regenerate proto
 ([`dd33577`](https://github.com/yandex-cloud/python-sdk/commit/dd33577437a835cbbc091bedf9c8994a015abdca))
* [Marketplace Metering API] Improve example.py ([`0462b65`](https://github.com/yandex-cloud/python-sdk/commit/0462b65ec106bd466b429e8163e4728eed7d0d58))
* Regenerate proto
 ([`ff7c76f`](https://github.com/yandex-cloud/python-sdk/commit/ff7c76f0821843d5942e5653c912eaf06b1f29b8))
* Regenerate proto
 ([`a739eb1`](https://github.com/yandex-cloud/python-sdk/commit/a739eb1e272a8a7d1c035b6abdf499d997582b28))
* Regenerate proto
 ([`c0634db`](https://github.com/yandex-cloud/python-sdk/commit/c0634db4dfc284aed391607ec1a8170cda508fd0))
* Regenerate proto
 ([`d912cb2`](https://github.com/yandex-cloud/python-sdk/commit/d912cb2da03e61778490686f19ef3c3d8210aaa4))
* Regenerate proto
 ([`28cf73a`](https://github.com/yandex-cloud/python-sdk/commit/28cf73ab9baf1e186cf8e822e0ace6e690ee5f33))
* Regenerate proto
 ([`3013d7d`](https://github.com/yandex-cloud/python-sdk/commit/3013d7d7bc9195d1b15d774928066af55cc687ca))
* Regenerate proto
 ([`d9e7979`](https://github.com/yandex-cloud/python-sdk/commit/d9e797919d9249d2eeb5a4674360cfe8720c17b3))
* Regenerate proto
 ([`e36f736`](https://github.com/yandex-cloud/python-sdk/commit/e36f73629db22f5e522cb51a240aa3e22f63c9d8))
* Regenerate proto
 ([`a78b380`](https://github.com/yandex-cloud/python-sdk/commit/a78b380074ffa58b114fa5e5e1c5922a39e955b7))
* Regenerate proto
 ([`f138646`](https://github.com/yandex-cloud/python-sdk/commit/f1386464fb529d63998dcba530608f2ec6dace45))
* Regenerate proto
 ([`0d3c4b0`](https://github.com/yandex-cloud/python-sdk/commit/0d3c4b0d84e76bf625d2788b23c0e7a895657176))
* Regenerate proto
 ([`21c05ee`](https://github.com/yandex-cloud/python-sdk/commit/21c05eef220085f53a6d58eff9a8c8c024d8133d))
* Regenerate proto
 ([`9e08c18`](https://github.com/yandex-cloud/python-sdk/commit/9e08c1853f2a4fc60aac44a31a3200d807d5f880))
* Merge pull request #13 from peter-volkov/master

RetryInterceptor fix, compatibility for different grpcio versions  ([`34896c4`](https://github.com/yandex-cloud/python-sdk/commit/34896c4b7f378fb24ca3b743f468f66c3251d24b))
* Import fix
 ([`26e6ced`](https://github.com/yandex-cloud/python-sdk/commit/26e6ced4c8b401f208cf0c65862353b5fd2d0114))
* Add backoff with jitter
 ([`112ec7c`](https://github.com/yandex-cloud/python-sdk/commit/112ec7cbdf9024c3297e581e0e593ac0c9600cff))
* Grpcio 1.34.1 compatibility
 ([`d3bc894`](https://github.com/yandex-cloud/python-sdk/commit/d3bc8949b93557ae6befbc8978269a727468009f))
* Fix interceptor
 ([`4a5461d`](https://github.com/yandex-cloud/python-sdk/commit/4a5461dd5d10fb6ff678c6c9177455dbf5dc024d))
* Regenerate proto
 ([`936b6aa`](https://github.com/yandex-cloud/python-sdk/commit/936b6aae73233349a6845ee7f70c70fe7015e27c))
* Merge pull request #12 from peter-volkov/patch-1

Per call timeout for default interceptor (for DEADLINE_EXCEEDED case) ([`7a0a113`](https://github.com/yandex-cloud/python-sdk/commit/7a0a1132fcc7528ee1904266bf4f905dc1f94539))
* Per call timeout for default interceptor (for DEADLINE_EXCEEDED case) ([`9804f56`](https://github.com/yandex-cloud/python-sdk/commit/9804f567aae7946cdec23c0c01124892c20c5ce2))
* Regenerate proto
 ([`925769c`](https://github.com/yandex-cloud/python-sdk/commit/925769cfefdc50e3d688be9f181a93c44e61bbe3))
* Regenerate proto
 ([`3896b00`](https://github.com/yandex-cloud/python-sdk/commit/3896b00c6e68479f6ab3ac7e55fcb65787d2cc4f))
* Regenerate proto
 ([`dd36125`](https://github.com/yandex-cloud/python-sdk/commit/dd36125305315f2ee372ef4d85e70772486ded00))
* Regenerate proto
 ([`6b9963b`](https://github.com/yandex-cloud/python-sdk/commit/6b9963b35134b522438f9bdcfd0b461d9779ce80))
* Regenerate proto
 ([`afdb884`](https://github.com/yandex-cloud/python-sdk/commit/afdb8849d39d7f8f822d90b72d40ae79b1ef112f))
* Regenerate proto
 ([`a7ea679`](https://github.com/yandex-cloud/python-sdk/commit/a7ea679226ed7652d4b5c4dd3c542f4c8f292b53))
* Bump version
 ([`69416bd`](https://github.com/yandex-cloud/python-sdk/commit/69416bd58c6e2a16dbea998752e8445979ebb158))
* Merge pull request #11 from peter-volkov/feature/MDB-10559/default_retry

MDB-10559 default retry interceptor ([`da52ad4`](https://github.com/yandex-cloud/python-sdk/commit/da52ad49216f1e60056c4c3b05d863c9cbbca9d0))
* MDB-10559 import class
 ([`ae198b0`](https://github.com/yandex-cloud/python-sdk/commit/ae198b0562d889ac4098c219ec9c54cf51577da6))
* MDB-10559 remove circular dep
 ([`96f8962`](https://github.com/yandex-cloud/python-sdk/commit/96f8962663d00fac602fce2421e681a5c71fb271))
* MDB-10559 use up to date flavor
 ([`7760f95`](https://github.com/yandex-cloud/python-sdk/commit/7760f95fe297ba849efb864b2523d225323d3e1a))
* MDB-10559 minimum 2 cores for standard-v1
 ([`ba07b03`](https://github.com/yandex-cloud/python-sdk/commit/ba07b035c061500fb4439f874749a4257505861b))
* MDB-10559 default retry interceptor
 ([`a2e08d7`](https://github.com/yandex-cloud/python-sdk/commit/a2e08d7112c51e43c451f5c882f3b26f696983f5))
* Regenerate proto
 ([`a096565`](https://github.com/yandex-cloud/python-sdk/commit/a09656528c484e713b17376b1a99fd19122a8518))
* Add managed kafka to supported modules
 ([`0eee4d4`](https://github.com/yandex-cloud/python-sdk/commit/0eee4d467e0584d1a4adef9889485cdd3e6b17b6))
* Regenerate proto
 ([`cc33852`](https://github.com/yandex-cloud/python-sdk/commit/cc338520969a2a583a13828083a5d5511cce69eb))
* Regenerate proto
 ([`2b613af`](https://github.com/yandex-cloud/python-sdk/commit/2b613af1291a60488c370c574cc984abcedcc759))
* Regenerate proto
 ([`f9712c0`](https://github.com/yandex-cloud/python-sdk/commit/f9712c0c39609f75a3c5720293a2d5518a130393))
* Regenerate proto
 ([`20e5bd8`](https://github.com/yandex-cloud/python-sdk/commit/20e5bd822605558b8039089ae4717cb4c001bdf3))
* Regenerate proto
 ([`8faf1b7`](https://github.com/yandex-cloud/python-sdk/commit/8faf1b75ac67f41d533591fcdde7c7c309d4e67c))
* Regenerate proto
 ([`a4edffa`](https://github.com/yandex-cloud/python-sdk/commit/a4edffa660eed65a5ce3c98dd875a8037bc04ee1))
* Regenerate proto
 ([`fcc50e3`](https://github.com/yandex-cloud/python-sdk/commit/fcc50e3a000da0819306e221b86731ca3634c494))
* Regenerate proto
 ([`632bc30`](https://github.com/yandex-cloud/python-sdk/commit/632bc301fc5a5d8bbbe36e454eddd8d382922b36))
* Regenerate proto
 ([`0f3dc4d`](https://github.com/yandex-cloud/python-sdk/commit/0f3dc4d33ef76815687f6a4eec011bcbb4df4f63))
* Regenerate proto
 ([`8dc49eb`](https://github.com/yandex-cloud/python-sdk/commit/8dc49eb97a35d150dc11f287a11869204c70f08e))
* Regenerate proto
 ([`0810a7d`](https://github.com/yandex-cloud/python-sdk/commit/0810a7d5ab40024dcfde51e276b890daf30ee748))
* Regenerate proto
 ([`f056ae3`](https://github.com/yandex-cloud/python-sdk/commit/f056ae3cf2014beb54f766e59ea367b3ba145ba2))
* Regenerate proto
 ([`88332e2`](https://github.com/yandex-cloud/python-sdk/commit/88332e22c5c519fde23138b42787dec74cdc75bd))
* Regenerate proto
 ([`853ec6e`](https://github.com/yandex-cloud/python-sdk/commit/853ec6e251e5479cf6c4f989215685f2ee8a3b70))
* Regenerate proto
 ([`c5dc88a`](https://github.com/yandex-cloud/python-sdk/commit/c5dc88ac2df4593d1726321637f7adaf3bb3585f))
* Regenerate proto
 ([`67ae80e`](https://github.com/yandex-cloud/python-sdk/commit/67ae80eb6447d33adbad2305b7441f5c98f9db71))
* Regenerate proto
 ([`f3c9c48`](https://github.com/yandex-cloud/python-sdk/commit/f3c9c4873fe95011e5f149a874868c5df28af2ed))
* Regenerate proto
 ([`ef8e1c1`](https://github.com/yandex-cloud/python-sdk/commit/ef8e1c1d1d717aee8bd7375af2cf88c908312962))
* Regenerate proto
 ([`6d515a9`](https://github.com/yandex-cloud/python-sdk/commit/6d515a9419da200d7d06c6c3c262865980849243))
* Regenerate proto
 ([`da26911`](https://github.com/yandex-cloud/python-sdk/commit/da26911ec32227c1af6dd86080e7deb5cce6bad9))
* Regenerate proto
 ([`6ac976b`](https://github.com/yandex-cloud/python-sdk/commit/6ac976b686dc98b3b6f7020476285b850502a183))
* Regenerate proto
 ([`49ac0e8`](https://github.com/yandex-cloud/python-sdk/commit/49ac0e8c4771658cf4df8b9c6c66b17bd7c384fd))
* Regenerate proto
 ([`b2257d1`](https://github.com/yandex-cloud/python-sdk/commit/b2257d109078959597e3ce149c69dee2c6190da0))
* Regenerate proto
 ([`3798e99`](https://github.com/yandex-cloud/python-sdk/commit/3798e99d82140da2205d26ad3b796527a506c2c7))
* Regenerate proto
 ([`791ba4c`](https://github.com/yandex-cloud/python-sdk/commit/791ba4cedef9fdb53029bed289af0fbe63f721d3))
* Regenerate proto
 ([`0cf9014`](https://github.com/yandex-cloud/python-sdk/commit/0cf90144a50082ee5be25422bb8a77f2da3ffc64))
* Regenerate proto
 ([`43d9403`](https://github.com/yandex-cloud/python-sdk/commit/43d9403b6d2544dde2e1ac1bf1bac67fa4164704))
* Regenerate proto
 ([`06fb910`](https://github.com/yandex-cloud/python-sdk/commit/06fb910d8e2e4fea690f6631af28d142e906e31b))
* Regenerate proto
 ([`ee440e9`](https://github.com/yandex-cloud/python-sdk/commit/ee440e906fd53a056598b2b606cf92304dba0daf))
* Regenerate proto
 ([`c338288`](https://github.com/yandex-cloud/python-sdk/commit/c33828836637cfb032b86603a73d9a8d46319680))
* Regenerate proto
 ([`b0858e0`](https://github.com/yandex-cloud/python-sdk/commit/b0858e0e4ad31cf8f02f862c842d8cf581f2fb53))
* Add metadata example to instance creation
 ([`6bc5de0`](https://github.com/yandex-cloud/python-sdk/commit/6bc5de0055781b86dfe13a4b5b60d41fbf1b0cb2))
* Regenerate proto
 ([`8fc6706`](https://github.com/yandex-cloud/python-sdk/commit/8fc6706bb0a204b22181a1f72b80b2253a909725))
* Regenerate proto
 ([`5b0abb9`](https://github.com/yandex-cloud/python-sdk/commit/5b0abb9df8eeb4d0d3ddc1b578275838f7f63f68))
* Regenerate proto
 ([`47b3585`](https://github.com/yandex-cloud/python-sdk/commit/47b3585aec55f5bb9301f50807febc9e0fa0d546))
* Regenerate proto
 ([`4812748`](https://github.com/yandex-cloud/python-sdk/commit/4812748eba49c6884e3f5d510518fde95984060c))
* Regenerate proto
 ([`7c3dd7a`](https://github.com/yandex-cloud/python-sdk/commit/7c3dd7aaa410748d3e2e00eb69a74f04d16b6fd7))
* Regenerate proto
 ([`1f81d3d`](https://github.com/yandex-cloud/python-sdk/commit/1f81d3d5b70357f23b7deb89a0a877c099e30294))
* Merge pull request #8 from peter-volkov/master

SA key usage in examples. Helper functions in SDK ([`8b234d3`](https://github.com/yandex-cloud/python-sdk/commit/8b234d33c03c3cb1ba96653af7d9ad05118bafca))
* Dataproc wrapper class
 ([`06fae44`](https://github.com/yandex-cloud/python-sdk/commit/06fae446f3a6302e245a7e5565310e4ee6bd2335))
* Use SA keys. Op wait helpers
 ([`2ee2382`](https://github.com/yandex-cloud/python-sdk/commit/2ee2382f04d405068e616dcea1c3bae24f23a6be))
* Check private SA key format
 ([`5895633`](https://github.com/yandex-cloud/python-sdk/commit/5895633be38fceb11d915207b91d05838ec1175f))
* Merge pull request #7 from kbespalov/add_mkt_example

Add example of Metering API usage ([`d62438c`](https://github.com/yandex-cloud/python-sdk/commit/d62438c5273018a644c8096456f677a87c1e2dce))
* Add retry && remove unsed LOG
 ([`4feadf8`](https://github.com/yandex-cloud/python-sdk/commit/4feadf88b979c9e4d393864ee56e528d239538b3))
* Fix docstring
 ([`ca1d9b3`](https://github.com/yandex-cloud/python-sdk/commit/ca1d9b3c104867884e52b06bcc350fa8d9ca54ec))
* Add example of Metering API usage
 ([`c8314c8`](https://github.com/yandex-cloud/python-sdk/commit/c8314c8c8fe95b79a66666ff7681d525ed6a2ea8))
* Regenerate proto
 ([`e86563e`](https://github.com/yandex-cloud/python-sdk/commit/e86563ee850e46a35b4c84053ecd4affdf66a963))
* Bump version to 0.20.0
 ([`188327e`](https://github.com/yandex-cloud/python-sdk/commit/188327efb8251d2ed070c1a755b81b99ebd88c5e))
* Version 0.20.0

* added metadata service auth
* fixed service account auth tests
* added nice readme
 ([`842df7d`](https://github.com/yandex-cloud/python-sdk/commit/842df7dc433af0c7a69f1c7bbbea3b5e83c30f35))
* Bump version to 0.19.1
 ([`6d27b9f`](https://github.com/yandex-cloud/python-sdk/commit/6d27b9f43f2a36eb499255291d33fd2cd9904599))
* Add marketplace module
 ([`121d602`](https://github.com/yandex-cloud/python-sdk/commit/121d6021a2d1da10df479cc1584ca31af4a6877a))
* Regenerate proto
 ([`0a037a8`](https://github.com/yandex-cloud/python-sdk/commit/0a037a80c372876cc2d26163167b2c450cf32e1b))
* Regenerate proto
 ([`2e4ddbe`](https://github.com/yandex-cloud/python-sdk/commit/2e4ddbe2bb4661ea2a7adb25c72414cd46bacd7e))
* Merge pull request #6 from peter-volkov/master

Added DataProc job run examples ([`023e3ad`](https://github.com/yandex-cloud/python-sdk/commit/023e3adf140abd21b0e270495074666baa748c48))
* Regenerate proto
 ([`b93bf03`](https://github.com/yandex-cloud/python-sdk/commit/b93bf037d0a9e3b1038c6e8a2a5a8d363a2eb001))
* Regenerate proto
 ([`3c350da`](https://github.com/yandex-cloud/python-sdk/commit/3c350dae3a94a11507888b414f070ff83a642040))
* Added DataProc job run examples
 ([`f937d99`](https://github.com/yandex-cloud/python-sdk/commit/f937d99aaec41606ae50330242b0df42c9af1618))
* Merge pull request #5 from peter-volkov/master

Use up to date resource presets. Add Redis, MySQL, Dataproc examples ([`76948a2`](https://github.com/yandex-cloud/python-sdk/commit/76948a2e402df9d37fb62032c9e5838aee8c2c07))
* Use up to date resource presets. Add Redis, MySQL, Dataproc examples
 ([`86990ca`](https://github.com/yandex-cloud/python-sdk/commit/86990ca541ea5a3401cb451d9fd1a639c467672a))
* Regenerate proto
 ([`5f80ab5`](https://github.com/yandex-cloud/python-sdk/commit/5f80ab549acbb25b888ed30f51d99e0e662dfa1f))
* Regenerate proto
 ([`707e8c3`](https://github.com/yandex-cloud/python-sdk/commit/707e8c31fbbb6cf545dbcd99b26a66aebecfc9a8))
* Update API, update supported services list, bump version
 ([`9d430b1`](https://github.com/yandex-cloud/python-sdk/commit/9d430b175da36cd5937602c822ae015c6b3dfa6a))
* Update API, update supported services list, bump version
 ([`b549bf4`](https://github.com/yandex-cloud/python-sdk/commit/b549bf419eefd9768c61aaa83d0611f84968711a))
* Update API, update supported services list, bump version
 ([`3d07818`](https://github.com/yandex-cloud/python-sdk/commit/3d0781868fc3e7b1502b4a6e3ea1f460c40337f7))
* Add classifiers to setup.py. Fixes gh-4
 ([`438db99`](https://github.com/yandex-cloud/python-sdk/commit/438db99d92310906d0bdee7b6ff95e6cd11b3000))
* Bump SDK version
 ([`8656260`](https://github.com/yandex-cloud/python-sdk/commit/8656260c692a8b617ba956941eb9b573158890c4))
* Generate pb
 ([`83c067f`](https://github.com/yandex-cloud/python-sdk/commit/83c067fd202a5c3012887daf3f8049ead53eab7b))
* Merge pull request #2 from Nyoroon/patch-1

Update operation status while accessing the done property of OperationWaiter ([`980e2c5`](https://github.com/yandex-cloud/python-sdk/commit/980e2c5d848eadb42799132b35a9f58ab7b27157))
* Genererate pb + update endpoints
 ([`a36e3c5`](https://github.com/yandex-cloud/python-sdk/commit/a36e3c59ba05f760977bcfcf8a7fe76e91c6d228))
* Actually do check operation in OperationWaiter

 Actually do check operation in OperationWaiter when accessing done property done. ([`38cc651`](https://github.com/yandex-cloud/python-sdk/commit/38cc6516125d5dbde8a905bd3c6cb7cff4ed29ae))
* Bump version
 ([`1d9451a`](https://github.com/yandex-cloud/python-sdk/commit/1d9451a8cc49cdb2acfabdafdc75a1c2b427d7bb))
* Added minimal grpcio version for retry interceptor to work
 ([`5d4716a`](https://github.com/yandex-cloud/python-sdk/commit/5d4716a0266798cc158899409f559a88f8d2602d))
* Support interceptors in SDK
 ([`8e7df81`](https://github.com/yandex-cloud/python-sdk/commit/8e7df81254c18396187197c766e8af5ecac5bedd))
* Generate missing __init__.py
 ([`898b9b2`](https://github.com/yandex-cloud/python-sdk/commit/898b9b264ae291c1ec86152e74ea37cff45b6a95))
* Merge pull request #1 from kuk/master

Updated API ([`8414615`](https://github.com/yandex-cloud/python-sdk/commit/8414615fb8e2a126948c2af232ad482e4c43245d))
* Updated API
 ([`9ed148c`](https://github.com/yandex-cloud/python-sdk/commit/9ed148c5f44016bbbe699e84530e6bb2b165948c))
* Added more credentials validation code. Added tests. Incremented version.
 ([`abcb314`](https://github.com/yandex-cloud/python-sdk/commit/abcb3141e0028046c18c5a77f97cc1d6a434a697))
* Put author_email to setup.py
 ([`9eac735`](https://github.com/yandex-cloud/python-sdk/commit/9eac7359fa4a907ad26020aa1fe0ad92fb0b1e46))
* Added operation waiter class/sdk method.
 ([`bcb1156`](https://github.com/yandex-cloud/python-sdk/commit/bcb1156bb527dcf69c920173bc54c3eaba461a4b))
* Added code that allows authorization with service_account_key.
 ([`4edbc5a`](https://github.com/yandex-cloud/python-sdk/commit/4edbc5a1c91d00396a4719966b9acbf134f29312))
* Added sdk examples for mdb.
 ([`5049ab4`](https://github.com/yandex-cloud/python-sdk/commit/5049ab47f621d73d9ac4571ea7db69b61d06c231))
* Added retry interceptor. Added some tests for it.
 ([`1cd8fea`](https://github.com/yandex-cloud/python-sdk/commit/1cd8feab1f588b302d26ead6773216277e9c2318))
* Update API
 ([`c4f0905`](https://github.com/yandex-cloud/python-sdk/commit/c4f0905170b1cc7987836843cbe7f268d3e72087))
* Add CONTRIBUTING.md
 ([`c2c7bf5`](https://github.com/yandex-cloud/python-sdk/commit/c2c7bf5e244722d44bfc960e7c9dfd4e4163e33c))
* Fix doing IAM requests on original endpoint
 ([`7c764a5`](https://github.com/yandex-cloud/python-sdk/commit/7c764a5abb0f02cd3cc4d697bdaf3272da1679c0))
* Python Client Library
 ([`85714ca`](https://github.com/yandex-cloud/python-sdk/commit/85714cab3a91799f47adb0316a99a567f57fc32f))
* Initial commit
 ([`9cdfbc1`](https://github.com/yandex-cloud/python-sdk/commit/9cdfbc172d751fad144b235a53a73a92e2335972))
